@@ -1,4 +1,4 @@
-magtri=function(chains, samples=1000, thin=1, samptype='end', grid=FALSE, tick=FALSE, refvals=NULL, ...){
+magtri=function(chains, samples=1000, thin=1, samptype='end', grid=FALSE, do.tick=FALSE, refvals=NULL, lab=NULL, ...){
   chains=as.data.frame(chains)
   chaincolnames=colnames(chains)
   Nsamp=dim(chains)[1]
@@ -44,7 +44,7 @@ magtri=function(chains, samples=1000, thin=1, samptype='end', grid=FALSE, tick=F
         xtemp=chains[usesamps,i]
         if(sd(xtemp)==0){xtemp=xtemp+rnorm(samples,sd=1e-3)}
         plot(density(xtemp),axes=FALSE,main='',xlim=xrange)
-        magaxis(1,grid=grid, grid.col = 'lightgrey',labels=FALSE,tick=tick)
+        magaxis(1,grid=grid, grid.col = 'lightgrey',labels=FALSE,do.tick=do.tick)
         abline(v=meanvec[i],lty=1,col='red')
         abline(v=meanvec[i]-sdvec[i],lty=3,col='red')
         abline(v=meanvec[i]+sdvec[i],lty=3,col='red')
@@ -54,7 +54,16 @@ magtri=function(chains, samples=1000, thin=1, samptype='end', grid=FALSE, tick=F
         box()
         if(i==1){
           plot.window(xlim=xrange,ylim=yrange)
-          magaxis(1:2,xlab=chaincolnames[i],ylab=chaincolnames[j])
+          if(is.null(lab)){
+            magaxis(1,xlab=chaincolnames[i])
+          }else{
+            magaxis(1,xlab=lab[[i]])
+          }
+          if(is.null(lab)){
+            magaxis(2,ylab=chaincolnames[j])
+          }else{
+            magaxis(2,ylab=lab[[j]])
+          }
         }
       }else{
         if(i>j){
@@ -64,7 +73,7 @@ magtri=function(chains, samples=1000, thin=1, samptype='end', grid=FALSE, tick=F
           ytemp=chains[usesamps,j]
           if(sd(xtemp)==0){xtemp=xtemp+rnorm(samples,sd=1e-3)}
           if(sd(ytemp)==0){ytemp=ytemp+rnorm(samples,sd=1e-3)}
-          magaxis(1:2,grid=grid, grid.col = 'lightgrey',labels=FALSE,tick=tick)
+          magaxis(1:2,grid=grid, grid.col = 'lightgrey',labels=FALSE,do.tick=do.tick)
           magcon(xtemp,ytemp,dobar=FALSE,doim=FALSE,add=TRUE,lty=c(2,1,3),xlim=xrange,ylim=yrange, h=c(diff(xrange),diff(yrange))/10, ...)
           points(meanvec[i],meanvec[j],col='red',pch=4,cex=2)
           box()
@@ -74,20 +83,32 @@ magtri=function(chains, samples=1000, thin=1, samptype='end', grid=FALSE, tick=F
           if(!is.null(refvals)){
             abline(v=refvals[i],lty=1, col='blue')
           }
-          if(j==1){magaxis(1,xlab=chaincolnames[i])}
+          if(j==1){
+            if(is.null(lab)){
+              magaxis(1,xlab=chaincolnames[i])
+            }else{
+              magaxis(1,xlab=lab[[i]])
+            }
+          }
         }else{
           plot.new()
           plot.window(xlim=xrange,ylim=yrange)
-          magaxis(1:2,grid=grid, grid.col = 'lightgrey',labels=FALSE,tick=tick)
+          magaxis(1:2,grid=grid, grid.col = 'lightgrey',labels=FALSE,do.tick=do.tick)
           points(chains[usesamps,c(i,j)],pch='.',col='darkgrey')
           points(meanvec[i],meanvec[j],col='red',pch=4,cex=2)
           box()
-          if(i==1){magaxis(2,ylab=chaincolnames[j])}
+          if(i==1){
+            if(is.null(lab)){
+              magaxis(2,ylab=chaincolnames[j])
+            }else{
+              magaxis(2,ylab=lab[[j]])
+            }
+          }
         }
       }
     }
   }
   output=cbind(mean=meanvec, sd=sdvec)
   rownames(output)=chaincolnames
-  return=output
+  return(invisible(output))
 }
